searchData={"items":[{"type":"module","title":"Snappywrap","doc":"A pure Elixir library to wrap a binary as _uncompressed_ data in Snappy format.\r\n\r\nThis library _does not_ provide compress/decompress functions, but only wraps the data\r\nin Snappy framing or block format that can be decompressed (decoded) by Snappy-compatible libraries.\r\n\r\nThis library is mostly for testing and/or low performance situations where using NIFs\r\nsuch as [`snappyrex`](https://github.com/c2bw/snappyrex) is not required.","ref":"Snappywrap.html"},{"type":"function","title":"Snappywrap.wrap/1","doc":"Wrap the data in Snappy `block` format.","ref":"Snappywrap.html#wrap/1"},{"type":"function","title":"Snappywrap.wrap_framed/1","doc":"Wrap the data in Snappy `framing` format.","ref":"Snappywrap.html#wrap_framed/1"},{"type":"module","title":"Snappywrap.Block","doc":"Store uncompressed data in Snappy block format.\r\n\r\nIn this wrapper implementation, each block can only be an uncompressed (literal) data block.\r\n\r\nSnappy output has the following format:\r\n- `preamble` - `varint block size`\r\n- `stream`: composed `of` only `literals` in this wrapper implementation\r\n\r\n\r\n1. Preamble\r\nThe stream starts with the uncompressed length (up to a maximum of 2^32 - 1),\r\nstored as a little-endian varint. Varints consist of a series of bytes,\r\nwhere the lower 7 bits are data and the upper bit is set iff there are\r\nmore bytes to be read. In other words, an uncompressed length of 64 would\r\nbe stored as 0x40, and an uncompressed length of 2097150 (0x1FFFFE)\r\nwould be stored as 0xFE 0xFF 0x7F.\r\n\r\n2. Compressed stream of Literals (00)\r\nLiterals are uncompressed data stored directly in the byte stream.\r\nThe literal length is stored differently depending on the length\r\nof the literal:\r\n\r\n- For literals up to and including 60 bytes in length, the upper\r\n six bits of the tag byte contain (len-1). The literal follows\r\n immediately thereafter in the bytestream.\r\n- For longer literals, the (len-1) value is stored after the tag byte,\r\n little-endian. The upper six bits of the tag byte describe how\r\n many bytes are used for the length; 60, 61, 62 or 63 for\r\n 1-4 bytes, respectively. The literal itself follows after the\r\n length.","ref":"Snappywrap.Block.html"},{"type":"function","title":"Snappywrap.Block.encode/1","doc":"Encodes as _uncompressed_ data in Snappy `block` format.\r\n\r\n  Input data size is assumed to be valid.","ref":"Snappywrap.Block.html#encode/1"},{"type":"module","title":"Snappywrap.Framing","doc":"The Snappy framing format is an optional Snappy format.\r\n\r\nIt consists of a stream identifier header `0xff 0x06 0x00 0x00 0x73 0x4e 0x61 0x50 0x70 0x59`, followed by a series of chunks.\r\nIn this wrapper implementation, each chunk can only be an uncompressed data chunk (identifier: `0x01`).\r\n\r\nSnappy chunks have the following format:\r\n- `1 byte`: chunk `type` (0x01 for uncompressed data)\r\n- `3 bytes`: chunk `length` (little-endian)\r\n- `4 bytes`: masked CRC-32C `checksum` of the chunk data\r\n- `N bytes`: chunk `data`","ref":"Snappywrap.Framing.html"},{"type":"function","title":"Snappywrap.Framing.encode/1","doc":"Encodes as _uncompressed_ data in Snappy `framing` format.\r\n\r\n  Input data size is assumed to be valid.","ref":"Snappywrap.Framing.html#encode/1"},{"type":"extras","title":"Snappywrap","doc":"# Snappywrap [![Hex Version](https://img.shields.io/hexpm/v/snappywrap.svg)](https://hex.pm/packages/snappywrap) [![Hex Docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/snappywrap/)\n\nA pure Elixir library to wrap a binary as _uncompressed_ data in Snappy format.\n\nThis library _does not_ provide compress/decompress functions, but only wraps the data\nin Snappy framing or block format that can be decompressed (decoded) by Snappy-compatible libraries.\n\nThis library is mostly for testing and/or low performance situations where using NIFs\nsuch as [`snappyrex`](https://github.com/c2bw/snappyrex) is not required.","ref":"readme.html"},{"type":"extras","title":"Installation - Snappywrap","doc":"The package can be installed by adding `snappywrap` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:snappywrap, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Snappywrap","doc":"```elixir\niex> Snappywrap.wrap(\"Hello, world!\")\n{:ok, \"\\r0Hello, world!\"}\niex> Snappywrap.wrap_framed(\"Hello, world!\")\n{:ok, <<255, 6, 0, 0, 115, 78, 97, 80, 112, 89, 1, 17, 0, 0, 26, 124, 78, 176, 72, 101, 108, 108, 111, 44, 32, 119, 111, 114, 108, 100, 33>>}\n```","ref":"readme.html#usage"},{"type":"extras","title":"LICENSE","doc":"MIT License\r\n\r\nCopyright (c) [2025] [c2bw]\r\n\r\nPermission is hereby granted, free of charge, to any person obtaining a copy\r\nof this software and associated documentation files (the \"Software\"), to deal\r\nin the Software without restriction, including without limitation the rights\r\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\r\ncopies of the Software, and to permit persons to whom the Software is\r\nfurnished to do so, subject to the following conditions:\r\n\r\nThe above copyright notice and this permission notice shall be included in all\r\ncopies or substantial portions of the Software.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\r\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\r\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\r\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\r\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\r\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\r\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}